==> haskell-lrucache-1.2.0.0-26-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-lrucache.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: lrucache
version: 1.2.0.0
id: lrucache-1.2.0.0-C8GpjBWjwLNByn59ZoaPMt
key: lrucache-1.2.0.0-C8GpjBWjwLNByn59ZoaPMt
license: BSD3
copyright: Carl Howells, 2010-2015
maintainer: chowells79@gmail.com
stability: Experimental
homepage: http://github.com/chowells79/lrucache
synopsis: a simple, pure LRU cache
description:
    This package contains a simple, pure LRU cache, implemented in
    terms of "Data.Map".
    .
    It also contains a mutable IO wrapper providing atomic updates to
    an LRU cache.
category: Data
author: Carl Howells
exposed: True
indefinite: False
exposed-modules:
    Data.Cache.LRU Data.Cache.LRU.IO Data.Cache.LRU.IO.Internal
    Data.Cache.LRU.Internal
abi: 46565b911d909841397802c0e5db8985
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/lrucache-1.2.0.0
library-dirs: /usr/lib/ghc-8.2.2/site-local/lrucache-1.2.0.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/lrucache-1.2.0.0
hs-libraries: HSlrucache-1.2.0.0-C8GpjBWjwLNByn59ZoaPMt
depends:
    base-4.10.1.0 containers-0.5.10.2
    contravariant-1.4.1-CaIS0FAz3wNFYESTGhl5v6
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             containers-0.5.10.2=0f9db0d1b935cacba444aac19f4cb54d
             contravariant-1.4.1-CaIS0FAz3wNFYESTGhl5v6=6a3c34b34c4bd5d9276d1724f3d09ec8
haddock-interfaces: /usr/share/doc/haskell-lrucache/html/lrucache.haddock
haddock-html: /usr/share/doc/haskell-lrucache/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-lrucache-1.2.0.0-29-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-lrucache.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: lrucache
version: 1.2.0.0
id: lrucache-1.2.0.0-DbxQJ7lCPu18HvbHFdzx8K
key: lrucache-1.2.0.0-DbxQJ7lCPu18HvbHFdzx8K
license: BSD-3-Clause
copyright: Carl Howells, 2010-2015
maintainer: chowells79@gmail.com
author: Carl Howells
stability: Experimental
homepage: http://github.com/chowells79/lrucache
synopsis: a simple, pure LRU cache
description:
    This package contains a simple, pure LRU cache, implemented in
    terms of "Data.Map".
    .
    It also contains a mutable IO wrapper providing atomic updates to
    an LRU cache.
category: Data
abi: fa3c9e451861d299fdb71fb7177afb6c
exposed: True
exposed-modules:
    Data.Cache.LRU Data.Cache.LRU.IO Data.Cache.LRU.IO.Internal
    Data.Cache.LRU.Internal
import-dirs: /usr/lib/ghc-8.4.3/site-local/lrucache-1.2.0.0
library-dirs: /usr/lib/ghc-8.4.3/site-local/lrucache-1.2.0.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/lrucache-1.2.0.0
hs-libraries: HSlrucache-1.2.0.0-DbxQJ7lCPu18HvbHFdzx8K
depends:
    base-4.11.1.0 containers-0.5.11.0
    contravariant-1.4.1-HAsNOXS6UjNLhhUqovtoIr
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             containers-0.5.11.0=94bb4831ae701bd40855b2dc2d65cf7c
             contravariant-1.4.1-HAsNOXS6UjNLhhUqovtoIr=c99faff75f3a482d24cfc7bf782693a7
haddock-interfaces: /usr/share/doc/haskell-lrucache/html/lrucache.haddock
haddock-html: /usr/share/doc/haskell-lrucache/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
